@@ -8,19 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_autoscaling._jsii
-import aws_cdk.aws_codedeploy._jsii
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_elasticloadbalancingv2._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@smallcase/aws-cdk-microservice",
-    "0.0.13",
+    "0.0.15",
     __name__[0:-6],
-    "aws-cdk-microservice@0.0.13.jsii.tgz",
+    "aws-cdk-microservice@0.0.15.jsii.tgz",
 )
 
 __all__ = [
